summaryrefslogtreecommitdiff
path: root/Master/tlpkg/TeXLive
diff options
context:
space:
mode:
authorSiep Kroonenberg <siepo@cybercomm.nl>2011-04-07 12:49:51 +0000
committerSiep Kroonenberg <siepo@cybercomm.nl>2011-04-07 12:49:51 +0000
commitc86eae6eafb31a01e822abfc17c31e25d846a9cc (patch)
treeca930cfc6e476a4daa82deb8d3df257fb6865369 /Master/tlpkg/TeXLive
parentc3c44f17a8ee71b0eff3d6c41290d25c0ed6d5d0 (diff)
rename DVD/CD => local-[un]compressed
git-svn-id: svn://tug.org/texlive/trunk@22010 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/tlpkg/TeXLive')
-rw-r--r--Master/tlpkg/TeXLive/TLMedia.pm18
-rw-r--r--Master/tlpkg/TeXLive/TLPDB.pm6
-rw-r--r--Master/tlpkg/TeXLive/TLPSRC.pm2
-rw-r--r--Master/tlpkg/TeXLive/TLUtils.pm30
4 files changed, 28 insertions, 28 deletions
diff --git a/Master/tlpkg/TeXLive/TLPDB.pm b/Master/tlpkg/TeXLive/TLPDB.pm
index 4f6c8fd5415..4f01c5899c4 100644
--- a/Master/tlpkg/TeXLive/TLPDB.pm
+++ b/Master/tlpkg/TeXLive/TLPDB.pm
@@ -994,9 +994,9 @@ sub sizes_of_packages {
$root =~ s!file://*!/!i;
$root = abs_path($root);
if (-d "$root/$Archive") {
- $media = 'CD';
+ $media = 'local_compressed';
} elsif (-d "$root/texmf/web2c") {
- $media = 'DVD';
+ $media = 'local_uncompressed';
} else {
die "$0: that should not happen, no proper location found!";
}
@@ -1010,7 +1010,7 @@ sub sizes_of_packages {
warn "STRANGE: $p not to be found in ", $self->root;
next;
}
- if ($media ne 'DVD') {
+ if ($media ne 'local_uncompressed') {
# we use the container size as the measuring unit since probably
# downloading will be the limiting factor
$tlpsizes{$p} = $tlpobjs{$p}->containersize;
diff --git a/Master/tlpkg/TeXLive/TLPSRC.pm b/Master/tlpkg/TeXLive/TLPSRC.pm
index e0ff4c2f813..beea50fdfde 100644
--- a/Master/tlpkg/TeXLive/TLPSRC.pm
+++ b/Master/tlpkg/TeXLive/TLPSRC.pm
@@ -716,7 +716,7 @@ This package collects some files which are not caught by any of the
other TL packages. Its primary purpose is to make the file coverage
check happy. The files here are not copied by the installer
and containers are not built; they exist only in the
-full DVD image.
+TeX Live Master tree.
=item B<00texlive.installer>
diff --git a/Master/tlpkg/TeXLive/TLMedia.pm b/Master/tlpkg/TeXLive/TLMedia.pm
index 09ef74e2d15..2c3be124b4b 100644
--- a/Master/tlpkg/TeXLive/TLMedia.pm
+++ b/Master/tlpkg/TeXLive/TLMedia.pm
@@ -58,9 +58,9 @@ sub new
$location = "/$1";
}
if (-d "$location/texmf/web2c") {
- $media = 'DVD';
+ $media = 'local_uncompressed';
} elsif (-d "$location/$Archive") {
- $media = 'CD';
+ $media = 'local_compressed';
} else {
# we cannot find the right type, return undefined, that should
# make people notice
@@ -180,9 +180,9 @@ sub install_package {
}
}
my $media = $self->media;
- if ($media eq 'DVD') {
+ if ($media eq 'local_uncompressed') {
$container = \@installfiles;
- } elsif ($media eq 'CD') {
+ } elsif ($media eq 'local_compressed') {
if (-r "$location/$Archive/$pkg.zip") {
$container = "$location/$Archive/$pkg.zip";
} elsif (-r "$location/$Archive/$pkg.tar.xz") {
@@ -196,9 +196,9 @@ sub install_package {
}
$self->_install_package ($container, $reloc, \@installfiles, $totlpdb)
|| return(0);
- # if we are installing from CD or NET we have to fetch the respective
+ # if we are installing from local_compressed or NET we have to fetch the respective
# source and doc packages $pkg.source and $pkg.doc and install them, too
- if (($media eq 'NET') || ($media eq 'CD')) {
+ if (($media eq 'NET') || ($media eq 'local_compressed')) {
# we install split containers under the following conditions:
# - the container were split generated
# - src/doc files should be installed
@@ -223,7 +223,7 @@ sub install_package {
|| return(0);
}
#
- # if we installed from NET/CD and we got a relocatable container
+ # if we installed from NET/local_compressed and we got a relocatable container
# make sure that the stray texmf-dist/tlpkg directory is removed
# in USER MODE that should NOT be done because we keep the information
# there, but for now do it unconditionally
@@ -326,7 +326,7 @@ sub _install_package {
$target .= "/$TeXLive::TLConfig::RelocTree" if $reloc;
# this is the case when we install from CD or the NET, or a backup
#
# in all other cases we create temp files .tar.xz (or use the present
# one), xzdec them, and then call tar
@@ -362,7 +362,7 @@ sub _install_package {
return(0);
}
} else {
- # we are installing from CD
+ # we are installing from local compressed files
# copy it to temp
copy($what, $tempdir);
}
@@ -326,7 +326,7 @@ sub _install_package {
$target .= "/$TeXLive::TLConfig::RelocTree" if $reloc;
- # this is the case when we install from CD or the NET, or a backup
+ # this is the case when we install from local_compressed or the NET, or a backup
#
# in all other cases we create temp files .tar.xz (or use the present
diff --git a/Master/tlpkg/TeXLive/TLUtils.pm b/Master/tlpkg/TeXLive/TLUtils.pm
index 793650e3b24..dc02e60ae70 100644
--- a/Master/tlpkg/TeXLive/TLUtils.pm
+++ b/Master/tlpkg/TeXLive/TLUtils.pm
@@ -1170,7 +1170,7 @@ the TLPDB given by C<$to_tlpdb>. Information on files are taken from
the TLPDB C<$from_tlpdb>.
C<$opt_src> and C<$opt_doc> specify whether srcfiles and docfiles should be
-installed (currently implemented only for installation from DVD).
+installed (currently implemented only for installation from uncompressed media).
Returns 1 on success and 0 on error.
@@ -1194,7 +1194,7 @@ sub install_packages {
if (!defined($tlpobjs{$p})) {
die "STRANGE: $p not to be found in ", $fromtlpdb->root;
}
- if ($media ne 'DVD') {
+ if ($media ne 'local_uncompressed') {
# we use the container size as the measuring unit since probably
# downloading will be the limiting factor
$tlpsizes{$p} = $tlpobjs{$p}->containersize;
@@ -1233,9 +1233,9 @@ sub install_packages {
push @installfiles, $tlpobj->allbinfiles;
push @installfiles, $tlpobj->srcfiles if ($opt_src);
push @installfiles, $tlpobj->docfiles if ($real_opt_doc);
- if ($media eq 'DVD') {
+ if ($media eq 'local_uncompressed') {
$container = [ $root, @installfiles ];
- } elsif ($media eq 'CD') {
+ } elsif ($media eq 'local_compressed') {
if (-r "$root/$Archive/$package.zip") {
$container = "$root/$Archive/$package.zip";
} elsif (-r "$root/$Archive/$package.tar.xz") {
@@ -1254,9 +1254,9 @@ sub install_packages {
# so only return here
return 0;
}
- # if we are installing from CD or NET we have to fetch the respective
+ # if we are installing from compressed media we have to fetch the respective
# source and doc packages $pkg.source and $pkg.doc and install them, too
- if (($media eq 'NET') || ($media eq 'CD')) {
+ if (($media eq 'NET') || ($media eq 'local_compressed')) {
# we install split containers under the following conditions:
# - the container were split generated
# - src/doc files should be installed
@@ -1301,7 +1301,7 @@ sub install_packages {
}
$totlpdb->add_tlpobj($tlpobj);
# we have to write out the tlpobj file since it is contained in the
# archives (.tar.xz) but at DVD install time we don't have them
my $tlpod = $totlpdb->root . "/tlpkg/tlpobj";
mkdirhier( $tlpod );
open(TMP,">$tlpod/".$tlpobj->name.".tlpobj") ||
@@ -1326,7 +1326,7 @@ This function installs the files given in @$filelistref from C<$what>
into C<$target>.
C<$size> gives the size in bytes of the container, or -1 if we are
-installing from DVD, i.e., from a list of files to be copied.
+installing from uncompressed media, i.e., from a list of files to be copied.
If C<$what> is a reference to a list of files then these files are
assumed to be readable and are copied to C<$target>, creating dirs on
@@ -1343,7 +1343,7 @@ file on the system and is likewise piped through C<xzdec> and C<tar>.
In both of these cases currently the list C<$@filelistref> currently
is not taken into account (should be fixed!).
-if C<$reloc> is true the container (NET or CD mode) is packaged in a way
+if C<$reloc> is true the container (NET or local_compressed mode) is packaged in a way
that the initial texmf-dist is missing.
Returns 1 on success and 0 on error.
@@ -1365,7 +1365,7 @@ sub install_package {
return 0;
}
if (ref $what) {
# we are getting a ref to a list of files, so install from DVD
my ($root, @files) = @$what;
foreach my $file (@files) {
# @what is taken, not @filelist!
@@ -1375,7 +1375,7 @@ sub install_package {
copy "$root/$file", "$target/$dn";
}
} elsif ($what =~ m,\.tar.xz$,) {
# this is the case when we install from CD or the NET
#
# in all other cases we create temp files .tar.xz (or use the present
# one), xzdec them, and then call tar
@@ -1452,7 +1452,7 @@ sub install_package {
return 0;
}
} else {
- # we are installing from CD
+ # we are installing from local compressed media
# copy it to temp
copy($what, $tempdir);
}
@@ -1475,7 +1475,7 @@ sub install_package {
if ($what =~ m,http://|ftp://,) {
# we downloaded the original .tar.lzma from the net, so we keep it
} else {
# we are downloading it from CD, so we can unlink it to save
# disk space
unlink($xzfile);
}
@@ -2115,7 +2115,7 @@ sub setup_programs {
}
} else {
if (!defined($platform) || ($platform eq "")) {
# we assume that we run from the DVD, so we can call platform() and
# thus also the config.guess script
# but we have to setup $::installerdir because the platform script
# relies on it
@@ -2180,7 +2180,7 @@ sub setup_unix_one {
#
# create tmp dir only when necessary
$tmp = TeXLive::TLUtils::tl_tmpdir() unless defined($tmp);
# probably we are running from DVD and want to copy it to
# some temporary location
copy($def, $tmp);
my $bn = basename($def);
@@ -1301,7 +1301,7 @@ sub install_packages {
$totlpdb->add_tlpobj($tlpobj);
# we have to write out the tlpobj file since it is contained in the
- # archives (.tar.xz) but at DVD install time we don't have them
+ # archives (.tar.xz) but at uncompressed-media install time we don't have them
my $tlpod = $totlpdb->root . "/tlpkg/tlpobj";
mkdirhier( $tlpod );
@@ -1365,7 +1365,7 @@ sub install_package {
}
if (ref $what) {
- # we are getting a ref to a list of files, so install from DVD
+ # we are getting a ref to a list of files, so install from uncompressed media
my ($root, @files) = @$what;
foreach my $file (@files) {
@@ -1375,7 +1375,7 @@ sub install_package {
}
} elsif ($what =~ m,\.tar.xz$,) {
- # this is the case when we install from CD or the NET
+ # this is the case when we install from compressed media
#
# in all other cases we create temp files .tar.xz (or use the present
@@ -1475,7 +1475,7 @@ sub install_package {
# we downloaded the original .tar.lzma from the net, so we keep it
} else {
- # we are downloading it from CD, so we can unlink it to save
+ # we are downloading it from local compressed media, so we can unlink it to save
# disk space
unlink($xzfile);
@@ -2115,7 +2115,7 @@ sub setup_programs {
} else {
if (!defined($platform) || ($platform eq "")) {
- # we assume that we run from the DVD, so we can call platform() and
+ # we assume that we run from uncompressed media, so we can call platform() and
# thus also the config.guess script
# but we have to setup $::installerdir because the platform script
@@ -2180,7 +2180,7 @@ sub setup_unix_one {
# create tmp dir only when necessary
$tmp = TeXLive::TLUtils::tl_tmpdir() unless defined($tmp);
- # probably we are running from DVD and want to copy it to
+ # probably we are running from uncompressed media and want to copy it to
# some temporary location
copy($def, $tmp);